@@ -143,6 +143,17 @@ class ModelMeta(type):
             )
         except AttributeError:
             pass
+        try:
+            frozen = new_cls.Meta.frozen
+        except AttributeError:
+            new_cls.Meta.frozen = False
+        try:
+            # mix values from Meta to an existing Meta Class
+            for key, _ in Meta.__annotations__.items():
+                if not hasattr(new_cls.Meta, key):
+                    setattr(new_cls.Meta, key, None)
+        except AttributeError:
+            pass
         dc = create_dataclass(
             new_cls,
             frozen=frozen
